MetaQuota — alfred3_interact

Skip to main content
`Ctrl`+`K`

# MetaQuota

class alfred3_interact.quota.MetaQuota(*quotas)

  Bases: `object`

  Gives access to aggregated information about open, pending, and finished slots of multiple individual quotas.

  Parameters

    *quotas – Variable number of quota

  Methods

  Attributes

  `allfinished` | True, if all slots are finished.
  `full` | True, if all quotas are full.
  `nfinished` | Number of finished slots.
  `nopen` | Number of open slots.
  `npending` | Number of pending slots.
  `nslots` | Total number of available slots.